@@ -2,10 +2,10 @@
 //! Contains the [`PlotNum`] trait and their supporting structs.
 //!
 
-//pub mod ext;
+use super::*;
 
 /// A disconnectable number. A number that can me marked as a hole to signify that there is a disconnect in plots.
-/// See [`crate::plottable::crop::Croppable`]
+/// See [`plottable::crop::Croppable`]
 ///
 pub trait DiscNum: PlotNum {
     /// Create a hole value.
@@ -27,18 +27,6 @@ pub trait PlotNum: PartialOrd + Copy {
     fn unit_range(offset: Option<Self>) -> [Self; 2];
 }
 
-///
-/// Used by [`crate::Bound`]
-///
-#[derive(Debug, Copy, Clone)]
-pub struct DashInfo {
-    //The ideal dash size in the drawing area
-    pub ideal_dash_size: f64,
-
-    //The total drawing area
-    pub max: f64,
-}
-
 ///
 /// Information on the properties of all the interval ticks for one dimension.
 ///
@@ -54,12 +42,12 @@ pub struct TickInfo<I: IntoIterator> {
 ///
 /// Trait to allow a plotnum to have a default tick distribution.
 ///
-/// Used by [`crate::DataResult::plot`]
+/// Used by [`Stager::plot`]
 ///
 pub trait HasDefaultTicks: PlotNum {
     type Fmt: TickFormat<Num = Self>;
     type IntoIter: IntoIterator<Item = Self>;
-    fn generate(bound: &crate::Bound<Self>) -> (TickInfo<Self::IntoIter>, Self::Fmt);
+    fn generate(bound: Bound<Self>) -> (TickInfo<Self::IntoIter>, Self::Fmt);
 }
 
 #[derive(Debug, Copy, Clone)]
@@ -140,7 +128,7 @@ impl<T: TickFormat, F: Fn(&mut dyn std::fmt::Write, &T::Num) -> std::fmt::Result
 use std::fmt;
 
 ///
-/// Used by [`crate::DataResult::plot_with`]
+/// Used by [`Stager::plot_with`]
 ///
 pub trait BaseFmt {
     type X: PlotNum;
