@@ -1,24 +1,16 @@
 use crate::*;
-
 mod render_base;
 mod render_plot;
 
-pub struct Extra<X, Y> {
-    pub canvas: render::Canvas,
-    pub boundx: Bound<X>,
-    pub boundy: Bound<Y>,
-    pub xtick_lines: bool,
-    pub ytick_lines: bool,
-    pub precision: usize,
-}
-
 ///
 /// Main render function.
 ///
 pub fn render<P: BaseAndPlotsFmt>(
     mut writer: impl fmt::Write,
     all: P,
-    extra: &Extra<P::X, P::Y>,
+    boundx: DataBound<P::X>,
+    boundy: DataBound<P::Y>,
+    canvas: Canvas,
 ) -> fmt::Result {
     let (base_fmt, plot_fmt) = all.gen();
 
@@ -31,8 +23,8 @@ pub fn render<P: BaseAndPlotsFmt>(
         })?;
     }
 
-    render::render_plot::render_plot(&mut writer, extra, plot_fmt)?;
-    render::render_base::render_base(&mut writer, extra, base_fmt)
+    render::render_plot::render_plot(&mut writer, &boundx, &boundy, &canvas, plot_fmt)?;
+    render::render_base::render_base(&mut writer, &boundx, &boundy, &canvas, base_fmt)
 }
 
 pub trait BaseAndPlotsFmt {
@@ -50,6 +42,7 @@ pub enum PlotType {
     Histo,
     LineFill,
     LineFillRaw,
+    Bars,
 }
 
 #[derive(Copy, Clone, Debug)]
@@ -94,107 +87,6 @@ pub trait BaseFmtAndTicks {
     fn gen(self) -> (Self::Fmt, TickInfo<Self::XI>, TickInfo<Self::YI>);
 }
 
-#[derive(Copy, Clone)]
-pub struct Canvas {
-    pub ideal_num_xsteps: u32,
-    pub ideal_num_ysteps: u32,
-    pub ideal_dash_size: f64,
-    width: f64,
-    height: f64,
-    padding: f64,
-    paddingy: f64,
-    xaspect_offset: f64,
-    yaspect_offset: f64,
-    pub scalex: f64,
-    pub scaley: f64,
-    spacing: f64,
-    legendx1: f64,
-    num_css_classes: Option<usize>,
-}
-impl Canvas {
-    pub fn get_dim(&self) -> [f64; 2] {
-        [self.width, self.height]
-    }
-    pub fn with_options<X: PlotNum, Y: PlotNum>(
-        boundx: [X; 2],
-        boundy: [Y; 2],
-        dim: Option<[f64; 2]>,
-        preserve_aspect: bool,
-        num_css_classes: Option<usize>,
-    ) -> Self {
-        let (width, height) = if let Some([x, y]) = dim {
-            (x, y)
-        } else {
-            (crate::WIDTH as f64, crate::HEIGHT as f64)
-        };
-
-        let ideal_dash_size = 20.0;
-        let padding = 150.0;
-        let paddingy = 100.0;
-
-        //The range over which the data will be scaled to fit
-        let (scalex, scaley) = if preserve_aspect {
-            if width > height {
-                (height - paddingy * 2.0, height - paddingy * 2.0)
-            } else {
-                (width - padding * 2.0, width - padding * 2.0)
-            }
-        } else {
-            (width - padding * 2.0, height - paddingy * 2.0)
-        };
-
-        let [minx, maxx] = boundx;
-        let [miny, maxy] = boundy;
-
-        let distancex_min_to_max =
-            maxx.scale([minx, maxx], scalex) - minx.scale([minx, maxx], scalex);
-        let distancey_min_to_max =
-            maxy.scale([miny, maxy], scaley) - miny.scale([miny, maxy], scaley);
-
-        let (xaspect_offset, yaspect_offset) = if preserve_aspect {
-            if width > height {
-                (-padding + width / 2.0 - distancey_min_to_max / 2.0, 0.0)
-            } else {
-                (
-                    0.0,
-                    -height + paddingy + height / 2.0 + distancey_min_to_max / 2.0,
-                )
-            }
-        } else {
-            (0.0, 0.0)
-        };
-
-        let ideal_xtick_spacing = 80.0;
-
-        let ideal_ytick_spacing = 60.0;
-
-        let ideal_num_xsteps = (distancex_min_to_max / ideal_xtick_spacing).floor() as u32;
-        let ideal_num_ysteps = (distancey_min_to_max / ideal_ytick_spacing).floor() as u32;
-        let ideal_num_xsteps = ideal_num_xsteps.max(2);
-        let ideal_num_ysteps = ideal_num_ysteps.max(2);
-
-        let spacing = padding / 3.0;
-        let legendx1 = width - padding / 1.2 + padding / 30.0;
-
-        Canvas {
-            ideal_num_xsteps,
-            ideal_num_ysteps,
-            ideal_dash_size,
-            width,
-            height,
-            padding,
-            paddingy,
-            xaspect_offset,
-            yaspect_offset,
-            scalex,
-            scaley,
-            spacing,
-            legendx1,
-            num_css_classes,
-        }
-    }
-}
-
 pub trait NumFmt {
     type K: Display;
     fn fmt(&self, a: f64) -> Self::K;
